# Introduction

It is used to generate tables of scores for bridge games

````
pip install pbr # install package
pbr sample      # download sample xlsx for reference student-group1.xlsx
                # edit xlsx for teams and add data in first sheet (sheet name with datetime like 2021-05-19)
pbr student-group1.xlsx
````

# Contact

* gopher in xinrui app
